Welcome to asq’s documentation! — asq 0.9 documentation

### Navigation

- index
- modules |
- next |
- asq 0.9 documentation »

# Welcome to asq’s documentation!

Asq is a Python package for specifying and performing efficient queries over collections of Python objects using a fluent interface. Asq can work with Python iterables of any type. The query interface is inspired by Microsoft’s LINQ API although adjustments have been made to make the interface more Pythonic, and all queries are represented using standard Python syntax with no support for in- language query syntax.

Contents:

- API Documentation for asq
  - asq
  - Parallel asq

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- modules |
- next |
- asq 0.9 documentation »